@@ -4,11 +4,11 @@
 //              Game class for Scid.
 //
 //  Part of:    Scid (Shane's Chess Information Database)
-//  Version:    3.2
+//  Version:    3.5
 //
-//  Notice:     Copyright (c) 2000-2002 Shane Hudson.  All rights reserved.
+//  Notice:     Copyright (c) 2000-2003 Shane Hudson.  All rights reserved.
 //
-//  Author:     Shane Hudson (shane@cosc.canterbury.ac.nz)
+//  Author:     Shane Hudson (sgh@users.sourceforge.net)
 //
 //////////////////////////////////////////////////////////////////////
 
@@ -49,6 +49,7 @@ const byte
     NAG_BlackDecisive = 19,
     NAG_WhiteCrushing = 20,
     NAG_BlackCrushing = 21,
+    NAG_Compensation = 44,
     NAG_Novelty = 146,
     NAG_Diagram = 201;  // Scid-specific NAGs start at 201.
 
@@ -101,6 +102,12 @@ struct moveT
     byte         nags[MAX_NAGS];
 };
 
+inline bool
+isNullMove (moveT * m)
+{
+    return isNullMove(&(m->moveData));
+}
+
 
 // Since we want allocation and freeing of moves to be FAST, we allocate
 // in chunks, and keep a linked list of the chunks allocated.
@@ -152,7 +159,8 @@ enum gameFormatT {
 #define PGN_STYLE_MOVENUM_SPACE  128   // Space after move numbers.
 #define PGN_STYLE_COLUMN         256   // Column style: one move per line.
 #define PGN_STYLE_SCIDFLAGS      512
-
+#define PGN_STYLE_STRIP_MARKS   1024   // Strip [%mark] and [%arrow] codes.
+#define PGN_STYLE_NO_NULL_MOVES 2048   // Convert null moves to comments.
 
 
 void  game_printNag (byte nag, char * str, bool asSymbol, gameFormatT format);
@@ -294,7 +302,7 @@ public:
     NameBase *  GetNameBase ()              { return NBase; }
 
     void        SetStartPos (Position * pos);
-    errorT      SetStartFen (char * fenStr);
+    errorT      SetStartFen (const char * fenStr);
 
     void        SetScidFlags (const char * s) { strCopy (ScidFlags, s); }
     const char * GetScidFlags ()              { return ScidFlags; }
@@ -323,7 +331,7 @@ public:
     errorT   FirstVariation (uint varNumber);
     errorT   MainVariation (uint varNumber);
 
-    void     SetMoveComment (char * comment);
+    void     SetMoveComment (const char * comment);
     char *   GetMoveComment () { return CurrentMove->prev->comment; }
 
     inline errorT AddNag (byte nag);
@@ -340,27 +348,28 @@ public:
     errorT   MoveIntoVariation (uint varNumber);
     errorT   MoveExitVariation ();
 
-    int      AtStart ()
+    bool     AtStart ()
                  { return (CurrentMove->prev->marker == START_MARKER  &&
                            VarDepth == 0); }
-    int      AtEnd ()
+    bool     AtEnd ()
                  { return (CurrentMove->marker == END_MARKER  &&
                            VarDepth == 0); }
-    int      AtVarStart ()
+    bool     AtVarStart ()
                  { return (CurrentMove->prev->marker == START_MARKER); }
-    int      AtVarEnd ()
+    bool     AtVarEnd ()
                  { return (CurrentMove->marker == END_MARKER); }
     uint     GetVarLevel () { return VarDepth; }
     uint      GetNumVariations ()
                  { return (uint) CurrentMove->numVariations; }
 
     void     Truncate ();
+    void     TruncateStart ();
 
-    void     SetEventStr (char * str);
-    void     SetSiteStr (char * str);
-    void     SetWhiteStr (char * str);
-    void     SetBlackStr (char * str);
-    void     SetRoundStr (char * str);
+    void     SetEventStr (const char * str);
+    void     SetSiteStr (const char * str);
+    void     SetWhiteStr (const char * str);
+    void     SetBlackStr (const char * str);
+    void     SetRoundStr (const char * str);
     void     SetDate (dateT date)    { Date = date; }
     void     SetEventDate (dateT date)  { EventDate = date; }
     void     SetResult (resultT res) { Result = res; }
@@ -388,7 +397,10 @@ public:
     ecoT     GetEco ()               { return EcoCode; }
     eloT     GetAverageElo ();
 
-    void     AddPgnTag (char * tag, char * value);
+    // Adding/Removing Extra  tags:
+    void     AddPgnTag (const char * tag, const char * value);
+    bool     RemoveExtraTag (const char * tag);
+    const char * FindExtraTag (const char * tag);
     uint     GetNumExtraTags ()      { return NumTags; }
     tagT *   GetExtraTags ()         { return TagList; }
     void     ClearExtraTags ();
@@ -405,9 +417,11 @@ public:
     // PGN conversion
     void      GetSAN (char * str);
     void      GetPrevSAN (char * str);
+    void      WriteComment (TextBuffer * tb, const char * preStr,
+                            const char * comment, const char * postStr);
     errorT    WriteMoveList (TextBuffer * tb, uint plyCount,
                              moveT * oldCurrentMove,
-                             bool printMoveNum);
+                             bool printMoveNum, bool inComment);
     errorT    WritePGN (TextBuffer * tb, uint stopLocation);
     errorT    WriteToPGN (TextBuffer * tb);
     errorT    MoveToLocationInPGN (TextBuffer * tb, uint stopLocation);
