@@ -4,11 +4,11 @@
 //              Index File Class
 //
 //  Part of:    Scid (Shane's Chess Information Database)
-//  Version:    3.2
+//  Version:    3.3
 //
 //  Notice:     Copyright (c) 2000-2002  Shane Hudson.  All rights reserved.
 //
-//  Author:     Shane Hudson (shane@cosc.canterbury.ac.nz)
+//  Author:     Shane Hudson (sgh@users.sourceforge.net)
 //
 //////////////////////////////////////////////////////////////////////
 
@@ -36,7 +36,7 @@
 static const char * sortCriteriaNames[] = {
     "Date", "Year", "Event", "Site", "Round",
     "White", "Black", "Eco", "Result", "Length",
-    "Rating", "Country", "Month", "Deleted", "EventDate", NULL
+    "Rating", "Country", "Month", "Deleted", "Eventdate", NULL
 };
 
 enum {
@@ -145,6 +145,21 @@ IndexEntry::SetEventDate (dateT edate)
     Dates = u32_set_high_12 (Dates, codedDate);
 }
 
+//~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+// IndexEntry::ValidEventDate():
+//    Given an event date, checks if it is close enough to the
+//    date to be encoded. Due to a compact encoding format,
+//    the EventDate must be within a few years of the Date.
+//    Returns true if the event date is encodable.
+bool
+IndexEntry::ValidEventDate (dateT edate)
+{
+    uint eyear = date_GetYear (edate);
+    uint dyear = date_GetYear (GetDate());
+    if (eyear < (dyear - 3)  ||  eyear > (dyear + 3)) { return false; }
+    return true;
+}
+
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 // IndexEntry::Read():
 //      Reads a single entrys values from an open index file.
@@ -184,6 +199,8 @@ IndexEntry::Read (MFile * fp, versionT version)
     // The two ELO ratings and rating types take 2 bytes each.
     WhiteElo = fp->ReadTwoBytes ();
     BlackElo = fp->ReadTwoBytes ();
+    if (GetWhiteElo() > MAX_ELO) { SetWhiteElo(MAX_ELO); }
+    if (GetBlackElo() > MAX_ELO) { SetBlackElo(MAX_ELO); }
 
     FinalMatSig = fp->ReadFourBytes ();
     NumHalfMoves = fp->ReadOneByte ();
@@ -409,8 +426,8 @@ IndexEntry::GetFlagStr (char * str, const char * flags)
 // IndexEntry::PrintGameInfo():
 //
 //      Prints the info for a single game to a string, according to the
-//      format string provided. Called by by sc_game_list() in tkscid.cc
-//      and from scidt.cc for its game listing (-l) option.
+//      format string provided. Called by by sc_game_list() in tkscid.cpp
+//      and from scidt.cpp for its game listing (-l) option.
 //
 //      The format string indicates what information to print. Non-letters
 //      in the string are printed as-is, while a letter (which should be
@@ -437,11 +454,11 @@ IndexEntry::GetFlagStr (char * str, const char * flags)
 void
 IndexEntry::PrintGameInfo (char * outStr,
                            gameNumberT gnFiltered, gameNumberT gnReal,
-                           NameBase * nb, char * format)
+                           NameBase * nb, const char * format)
 {
     ASSERT (outStr != NULL  &&  nb != NULL  &&  format != NULL);
 
-    char * s = format;
+    const char * s = format;
     char * out = outStr;
     *out = 0;
     char temp [256];
@@ -800,7 +817,7 @@ IndexEntry::Compare (IndexEntry * ie, int * fields, NameBase * nb)
                 dateT d2 = ie->GetEventDate();
                 if (d == ZERO_DATE) { d = GetDate(); }
                 if (d2 == ZERO_DATE) { d2 = ie->GetDate(); }
-                res = (int)d - (int)d;
+                res = (int)d - (int)d2;
             }
             break;
 
@@ -1122,7 +1139,7 @@ Index::ReadEntireFile (int reportFrequency,
         //printf ("Chunk %u: %u games\n", chunkCount, gamesToRead);
     }
     if (progressFn != NULL) {
-        (*progressFn) (progressData, GetNumGames(), GetNumGames());
+        (*progressFn) (progressData, 1, 1);
     }
     InMemory = true;
     return OK;
@@ -1235,11 +1252,11 @@ Index::WriteEntries (IndexEntry * ie, uint start, uint count)
 //      Sets the database description string.
 //
 void
-Index::SetDescription (char * str)
+Index::SetDescription (const char * str)
 {
     ASSERT (str != NULL);
     uint i;
-    char *s = str;
+    const char *s = str;
 
     // First erase the old description:
 
@@ -1450,6 +1467,9 @@ Index::Sort (NameBase * nb, int reportFrequency,
             reportAfter = reportFrequency;
         }
     }
+    if (progressFn != NULL) {
+        (*progressFn) (progressData, 1, 1);
+    }
 
     // Now EntriesHeap[] contains the index for the sorted order.
     // Entries[] is not actually changed, so the results of the
@@ -1553,22 +1573,23 @@ Index::WriteSorted (int reportFrequency,
 
         IndexEntry * ie;
         int reportAfter = reportFrequency;
-        uint progressCounter = 0;
         for (uint count=1; count <= Header.numGames; count++) {
             ie = FetchEntry(EntriesHeap[count]);
             ie->Write (FilePtr, Header.version);
             FilePos += IndexEntrySize;
-            progressCounter++;
             reportAfter--;
             if (reportAfter <= 0) {
                 if (progressFn != NULL) {
-                    (*progressFn) (progressData, progressCounter, GetNumGames());
+                    (*progressFn) (progressData, count, GetNumGames());
                 }
                 reportAfter = reportFrequency;
             }
         }
         if (FileMode == FMODE_Both) { FilePtr->Flush(); }
     }
+    if (progressFn != NULL) {
+        (*progressFn) (progressData, 1, 1);
+    }
     Dirty = 1;
     delete[] EntriesHeap;
     EntriesHeap = NULL;
