@@ -8,7 +8,7 @@
 //
 //  Notice:     Copyright (c) 1999-2002  Shane Hudson.  all rights reserved.
 //
-//  Author:     Shane Hudson (shane@cosc.canterbury.ac.nz)
+//  Author:     Shane Hudson (sgh@users.sourceforge.net)
 //
 //////////////////////////////////////////////////////////////////////
 
@@ -28,13 +28,13 @@
 
 const char         INDEX_SUFFIX[]     = ".si3";
 const char         OLD_INDEX_SUFFIX[] = ".si";
-const gameNumberT  MAX_GAMES         = 4000000;  // max. no. of games in file
-const char         INDEX_MAGIC[8]    = "Scid.si";
+const char         INDEX_MAGIC[8]     = "Scid.si";
+const gameNumberT  MAX_GAMES          = 16000000;  // max. # of games in file
 
 // Descriptions can be up to 107 bytes long.
 const uint  SCID_DESC_LENGTH = 107;
 
-const uint  MAX_ELO = 4095;   // Since we store Elo Ratings in 12 bits
+const uint  MAX_ELO = 4000;   // Since we store Elo Ratings in 12 bits
                               // each in the index file.
 
 // Struct indexHeader: one at the start of the index file.
@@ -272,6 +272,7 @@ class IndexEntry
         Dates = u32_set_low_20 (Dates, date);
     }
     void   SetEventDate (dateT date);
+    bool   ValidEventDate (dateT date);
 
     inline void SetResult (resultT res) {
         VarCounts = (VarCounts & 0x0FFF) | (((ushort)res) << 12);
@@ -342,7 +343,7 @@ class IndexEntry
 
     void PrintGameInfo (char * outStr,
                         gameNumberT gnFiltered, gameNumberT gnReal,
-                        NameBase * nb, char * format);
+                        NameBase * nb, const char * format);
 
     int Compare (IndexEntry * ie, int * fields, NameBase * nb);
 };
@@ -558,8 +559,8 @@ class Index
     versionT    GetVersion ()             { return Header.version; }
     void        SetVersion (versionT v)   { Header.version = v; }
 
-    void        SetDescription (char *s);
-    char *      GetDescription ()  { return Header.description; }
+    void        SetDescription (const char *s);
+    const char * GetDescription ()  { return Header.description; }
 
     void        SetAutoLoad (gameNumberT gnum) { Header.autoLoad = gnum + 1; }
     gameNumberT GetAutoLoad () {
