@@ -342,6 +342,36 @@ strCompareRound (const char * sleft, const char * sright)
     int iright = strGetInteger (sright);
     int diff = ileft - iright;
     if (diff != 0) { return diff; }
+
+    // Now check if both strings are equal up to the first dot.
+    // If so, do an integer comparison after the ".":
+
+    bool equalUpToDot = false;
+    const char * templeft = sleft;
+    const char * tempright = sright;
+
+    while (true) {
+        char leftc = *templeft;
+        char rightc = *tempright;
+        if (leftc == 0  ||  rightc == 0) { break; }
+        if (leftc != rightc) { break; }
+        if (leftc == '.'  &&  rightc == '.') { equalUpToDot = true; break; }
+        templeft++;
+        tempright++;
+    }
+
+    if (equalUpToDot) {
+        templeft++;
+        tempright++;
+        // Now templeft and tempright point to the first character
+        // after each dot.
+        ileft = strGetInteger (templeft);
+        iright = strGetInteger(tempright);
+        diff = ileft - iright;
+        if (diff != 0) { return diff; }
+    }
+    
+    // Give up on integer comparisons and do a regular string comparison:
     return strCompare (sleft, sright);
 }
 
