@@ -8,7 +8,7 @@
 //
 //  Notice:     Copyright (c) 1999-2000  Shane Hudson.  All rights reserved.
 //
-//  Author:     Shane Hudson (shane@cosc.canterbury.ac.nz) 
+//  Author:     Shane Hudson (sgh@users.sourceforge.net)
 //
 //////////////////////////////////////////////////////////////////////
 
@@ -21,6 +21,7 @@
 #include "error.h"
 #include "pbook.h"
 #include "misc.h"
+#include "mfile.h"
 
 #include <stdio.h>
 #include <string.h>
@@ -83,7 +84,6 @@ PBook::Init ()
     LeastMaterial = PBOOK_MAX_MATERIAL;
     SkipCount = 0;
     FileName = NULL;
-    UseEnPassentField = true;
     for (uint t=0; t <= PBOOK_MAX_MATERIAL; t++) {
         Tree[t] = new StrTree<bookDataT>;
     }
@@ -127,7 +127,7 @@ PBook::Clear ()
 }
 
 void
-PBook::SetFileName (char * fname)
+PBook::SetFileName (const char * fname)
 {
     if (FileName) { delete[] FileName; }
     if (!fname) { FileName = NULL; return; }
@@ -187,7 +187,7 @@ PBook::Find (Position * pos, const char ** ptrComment)
 
     // Generate the compact board string for this position, and lookup:
     compactBoardStr cboard;
-    pos->PrintCompactStr (cboard, UseEnPassentField);
+    pos->PrintCompactStr (cboard);
     bookNodeT * node = Tree[material]->Lookup (cboard);
     if (!node) { return ERROR_NotFound; }
     if (ptrComment) { *ptrComment = node->data.comment; }
@@ -279,6 +279,7 @@ PBook::FindNext (Position * pos, bool forwards)
     ASSERT (node != NULL);
     errorT err = pos->ReadFromCompactStr ((const byte *) node->name);
     if (err != OK) { return err; }
+    pos->SetEPTarget (node->data.enpassant);
 
     // Now print to FEN and re-read, to ensure the piece lists are in
     // the order produced by a FEN specification -- this is necessary
@@ -305,7 +306,7 @@ PBook::Insert (Position * pos, const char * comment)
     
     uint material = pos->GetCount(WHITE) + pos->GetCount(BLACK);
     compactBoardStr cboard;
-    pos->PrintCompactStr (cboard, UseEnPassentField);
+    pos->PrintCompactStr (cboard);
     err = Tree[material]->Insert (cboard, &node);
     if (err != OK) {  // Already exists; we overwrite the old data.
         delete[] node->data.comment;
@@ -314,6 +315,7 @@ PBook::Insert (Position * pos, const char * comment)
         AddNodeToList (node);
     }
     node->data.comment = strDuplicate (comment);
+    node->data.enpassant = pos->GetEPTarget();
     Altered = true;
 
     if (material < LeastMaterial) {
@@ -332,7 +334,7 @@ PBook::Delete (Position * pos)
 {
     uint material = pos->GetCount(WHITE) + pos->GetCount(BLACK);
     compactBoardStr cboard;
-    pos->PrintCompactStr (cboard, UseEnPassentField);
+    pos->PrintCompactStr (cboard);
     bookNodeT * node = Tree[material]->Delete (cboard);
     if (!node) { return ERROR_NotFound; }
 
@@ -524,7 +526,7 @@ PBook::ReadEcoFile ()
         pos.StdStart();
         err = pos.ReadLine (moves.Data());
         if (err != OK) { goto corrupt; }
-        text.Append ("moves ", strTrimLeft (moves.Data(), ' '), "\n");
+        text.Append ("moves ", strTrimLeft (moves.Data()), "\n");
         if (Insert (&pos, text.Data()) != OK) {
             // Position already exists: just ignore it.
         }
@@ -555,14 +557,18 @@ PBook::ReadFile ()
     LineCount = 1;
     Position * pos = new Position;
     DString * line = new DString;
-    line->ReadLine (&fp);
+    fp.ReadLine (line);
     DString dstr;
     
     while (! fp.EndOfFile()) {
 
         if (pos->ReadFromFEN (line->Data()) != OK) {
             fprintf (stderr, "Error reading line: %u\n", LineCount);
-            exit (1);
+            LineCount++;
+            line->Clear();
+            fp.ReadLine (line);
+            continue;
+            //exit (1);
         }
 
         char * s = (char *) line->Data();
@@ -600,12 +606,13 @@ PBook::ReadFile ()
         }
         LineCount++;
         line->Clear();
-        line->ReadLine (&fp);
+        fp.ReadLine (line);
     }
     delete pos;
     delete line;
     fp.Close();
     Altered = false;
+    NextIndex = NodeListCount - 1;
     return OK;
 }
 
@@ -632,6 +639,7 @@ PBook::WriteFile ()
             delete pos;
             return ERROR_Corrupt;
         }
+        pos->SetEPTarget (node->data.enpassant);
         pos->PrintFEN (tempStr, FEN_CASTLING_EP);
         fprintf (fp, "%s", tempStr);
         Stats_PositionBytes += strLength (tempStr);
@@ -690,4 +698,3 @@ PBook::DumpStats (FILE * fp)
 //////////////////////////////////////////////////////////////////////
 //  EOF: pbook.cpp
 //////////////////////////////////////////////////////////////////////
-
