@@ -4,11 +4,11 @@
 //              PgnParser class methods
 //
 //  Part of:    Scid (Shane's Chess Information Database)
-//  Version:    3.1
+//  Version:    3.5
 //
-//  Notice:     Copyright (c) 2001  Shane Hudson.  All rights reserved.
+//  Notice:     Copyright (c) 2001-2003  Shane Hudson.  All rights reserved.
 //
-//  Author:     Shane Hudson (shane@cosc.canterbury.ac.nz)
+//  Author:     Shane Hudson (sgh@users.sourceforge.net)
 //
 //////////////////////////////////////////////////////////////////////
 
@@ -41,6 +41,8 @@ PgnParser::Reset()
     StorePreGameText = true;
     EndOfInputWarnings = true;
     ResultWarnings = true;
+    NewlinesToSpaces = true;
+    NumIgnoredTags = 0;
 }
 
 void
@@ -79,6 +81,33 @@ PgnParser::Reset (const char * inbuffer)
     EndChar = 0;
 }
 
+void
+PgnParser::AddIgnoredTag (const char * tag)
+{
+    if (NumIgnoredTags >= MAX_IGNORED_TAGS) { return; }
+    if (tag == NULL  ||  tag[0] == 0) { return; }
+    IgnoredTags [NumIgnoredTags] = strDuplicate (tag);
+    NumIgnoredTags++;
+}
+
+void
+PgnParser::ClearIgnoredTags ()
+{
+    for (uint i = 0; i < NumIgnoredTags; i++) {
+        delete[] IgnoredTags[i];
+    }
+    NumIgnoredTags = 0;
+}
+
+bool
+PgnParser::IsIgnoredTag (const char * tag)
+{
+    for (uint i = 0; i < NumIgnoredTags; i++) {
+        if (strEqual (tag, IgnoredTags[i])) { return true; }
+    }
+    return false;
+}
+
 void
 PgnParser::LogError (const char * errMessage, const char * text)
 {
@@ -265,7 +294,7 @@ PgnParser::ExtractPgnTag (const char * buffer, Game * game)
         standardPlayerName (value);
 #endif
         // Check for a rating in parentheses at the end of the player name:
-        eloT elo = 0;
+        uint elo = 0;
         uint len = strLength (value);
         if (len > 7  &&  value[len-1] == ')'
             &&  isdigit(value[len-2])  &&  isdigit(value[len-3])
@@ -273,6 +302,10 @@ PgnParser::ExtractPgnTag (const char * buffer, Game * game)
             &&  value[len-6] == '('  &&  value[len-7] == ' ') {
             value[len-7] = 0;
             elo = strGetUnsigned (&(value[len-5]));
+            if (elo > MAX_ELO) {
+                LogError ("Warning: rating too large: ", value);
+                elo = MAX_ELO;
+            }
             game->SetWhiteElo (elo);
             game->SetWhiteRatingType (RATING_Elo);
         }
@@ -283,7 +316,7 @@ PgnParser::ExtractPgnTag (const char * buffer, Game * game)
         standardPlayerName (value);
 #endif
         // Check for a rating in parentheses at the end of the player name:
-        eloT elo = 0;
+        uint elo = 0;
         uint len = strLength (value);
         if (len > 7  &&  value[len-1] == ')'
             &&  isdigit(value[len-2])  &&  isdigit(value[len-3])
@@ -291,6 +324,10 @@ PgnParser::ExtractPgnTag (const char * buffer, Game * game)
             &&  value[len-6] == '('  &&  value[len-7] == ' ') {
             value[len-7] = 0;
             elo = strGetUnsigned (&(value[len-5]));
+            if (elo > MAX_ELO) {
+                LogError ("Warning: rating too large: ", value);
+                elo = MAX_ELO;
+            }
             game->SetBlackElo (elo);
             game->SetBlackRatingType (RATING_Elo);
         }
@@ -347,6 +384,10 @@ PgnParser::ExtractPgnTag (const char * buffer, Game * game)
             while (ratingTypeNames[i] != NULL) {
                 if (strEqual (tagSuffix, ratingTypeNames[i])) {
                     uint elo = strGetUnsigned (value);
+                    if (elo > MAX_ELO) {
+                        LogError ("Warning: rating too large: ", value);
+                        elo = MAX_ELO;
+                    }
                     game->SetWhiteElo (elo);
                     game->SetWhiteRatingType (i);
                     isRatingType = true;
@@ -361,6 +402,10 @@ PgnParser::ExtractPgnTag (const char * buffer, Game * game)
             while (ratingTypeNames[i] != NULL) {
                 if (strEqual (tagSuffix, ratingTypeNames[i])) {
                     uint elo = strGetUnsigned (value);
+                    if (elo > MAX_ELO) {
+                        LogError ("Warning: rating too large: ", value);
+                        elo = MAX_ELO;
+                    }
                     game->SetBlackElo (elo);
                     game->SetBlackRatingType (i);
                     isRatingType = true;
@@ -370,7 +415,7 @@ PgnParser::ExtractPgnTag (const char * buffer, Game * game)
             }
         }
 
-        if (! isRatingType) {
+        if (! isRatingType  &&  ! IsIgnoredTag (tag)) {
             game->AddPgnTag (tag, value);
         }
     }
@@ -395,7 +440,7 @@ PgnParser::GetComment (char * buffer, uint bufSize)
     int startLine = LineCounter;
     ch = GetChar();
     while (ch != EndChar  &&  ch != '}') {
-        if (ch == '\n') { ch = ' '; }
+        if (NewlinesToSpaces  &&  ch == '\n') { ch = ' '; }
         if (bufSize > 0) { *outPtr++ = (char) ch; bufSize--; }
         ch = GetChar();
     }
@@ -451,6 +496,18 @@ PgnParser::GetRestOfWord_WithDots (char * buffer)
     *buffer = 0;
 }
 
+void
+PgnParser::GetRestOfWord_Letters (char * buffer)
+{
+    int ch = GetChar();
+    while (isalpha(ch)) {
+        *buffer++ = ch;
+        ch = GetChar();
+    }
+    UnGetChar (ch);
+    *buffer = 0;
+}
+
 tokenT
 PgnParser::GetRestOfCastling (char * buffer)
 {
@@ -694,6 +751,12 @@ PgnParser::GetGameToken (char * buffer, uint bufSize)
     if (ch >= 'a'  &&  ch <= 'h') {   // Pawn move.
         return GetRestOfPawnMove (buf);
     }
+    if (ch == 'P') {
+        // Treat "P..." as a pawn move, ignoring the initial "P":
+        buf = buffer;
+        ADDCHAR (buf, GetChar());
+        return GetRestOfPawnMove (buf);
+    }
     if (ch == 'N'  ||  ch == 'B'  ||  ch == 'R'  ||  ch == 'Q'  ||  ch == 'K') {
         return GetRestOfMove (buf);
     }
@@ -701,6 +764,15 @@ PgnParser::GetGameToken (char * buffer, uint bufSize)
         return GetRestOfCastling (buf);
     }
 
+    // Check for null move:
+    if (ch == 'n') {
+        GetRestOfWord_Letters (buf);
+        if (strEqual (buffer, "null")) {
+            return TOKEN_Move_Null;
+        }
+        return TOKEN_Invalid;
+    }
+
     // Now we check for other tokens.......
     if (ch == ';'  ||  ch == '%') {
         // LineComment.  "%" should only mark a comment if at the start of
@@ -712,6 +784,10 @@ PgnParser::GetGameToken (char * buffer, uint bufSize)
         return TOKEN_Comment;
     }
 
+    if (ch == '}') {   // Close-brace outside a comment. Should not happen.
+        return TOKEN_CommentEnd;
+    }
+
     if (ch == '(') {   // variation. We let caller parse it out.
         return TOKEN_VarStart;
     }
@@ -719,6 +795,10 @@ PgnParser::GetGameToken (char * buffer, uint bufSize)
 
     if (ch == '!'  ||  ch == '?'  ||  ch == '='  ||  ch == '-') {   // Suffix
         GetRestOfSuffix (buf, ch);
+        // Treat the sequence "--" as a null move:
+        if (strEqual (buffer, "--")) {
+            return TOKEN_Move_Null;
+        }
         return TOKEN_Suffix;
     }
     if (ch == '$') {   // NAG
@@ -771,6 +851,7 @@ PgnParser::GetGameToken (char * buffer, uint bufSize)
     // Probably a letter like C or z, or punctuation or nonprintable.
 
     GetRestOfWord_WithDots (buf);
+    // Any other null-move notations to be checked for here?
     return TOKEN_Invalid;
 }
 
@@ -848,11 +929,23 @@ PgnParser::GetNextToken (char * buffer, uint bufSize)
 
 
 errorT
-PgnParser::ParseMoves (Game * game, char * buffer, int bufSize)
+PgnParser::ParseMoves (Game * game)
+{
+    char * buffer = new char [MAX_COMMENT_SIZE];
+    errorT err = ParseMoves (game, buffer, MAX_COMMENT_SIZE);
+    delete[] buffer;
+    return err;
+}
+   
+
+errorT
+PgnParser::ParseMoves (Game * game, char * buffer, uint bufSize)
 {
     errorT err = OK;
     uint moveErrorCount  = 0;
     const uint maxMoveErrorsPerGame = 1;
+    uint commentErrorCount = 0;
+    const uint maxCommentErrorsPerGame = 1;
     simpleMoveT sm;
     byte nag;
 
@@ -867,10 +960,38 @@ PgnParser::ParseMoves (Game * game, char * buffer, int bufSize)
         case TOKEN_Move_Piece:
         case TOKEN_Move_Castle_King:
         case TOKEN_Move_Castle_Queen:
+        case TOKEN_Move_Null:
             err = game->GetCurrentPos()->ReadMove (&sm, buffer, token);
+
+            // The most common type of "illegal" move in standard
+            // chess is castling when the king or rook have already
+            // moved. So if a castling move failed, turn off
+            // strict checking of castling rights and try again,
+            // but still print a warning if that succeeded:
+
+            if (err != OK  &&  (token == TOKEN_Move_Castle_King  ||
+                                token == TOKEN_Move_Castle_Queen)) {
+                bool prevFlag = game->GetCurrentPos()->GetStrictCastling();
+                game->GetCurrentPos()->SetStrictCastling (false);
+                err = game->GetCurrentPos()->ReadMove (&sm, buffer, token);
+                game->GetCurrentPos()->SetStrictCastling (prevFlag);
+
+                // If no longer an error, castling without strict checking
+                // worked, but still print a warning about it:
+                if (err == OK) {
+                    char tempStr[500];
+                    sprintf (tempStr, "(%s) in game %s - %s, %u",
+                             buffer, game->GetWhiteStr(), game->GetBlackStr(),
+                             date_GetYear (game->GetDate()));
+                    LogError ("Warning: illegal castling ", tempStr);
+                }
+            }
+
             if (err == OK  &&  moveErrorCount == 0) {
                 err = game->AddMove (&sm, NULL);
             }
+
+             // Report an error if the move could not be added:
             if (err != OK) {
                 moveErrorCount++;
                 if (moveErrorCount <= maxMoveErrorsPerGame) {
@@ -929,6 +1050,14 @@ PgnParser::ParseMoves (Game * game, char * buffer, int bufSize)
         case TOKEN_LineComment:
             break;  // Line comments inside a game are just ignored.
 
+        case TOKEN_CommentEnd:
+            if (commentErrorCount < maxCommentErrorsPerGame) {
+                LogError ("Warning: close-brace character \"}\" seen ",
+                          "outside a comment.");
+                commentErrorCount++;
+            }
+            break;
+
         case TOKEN_Tag:
             LogError ("Error: PGN Header tag seen inside a game", "");
             return ERROR_Game;
