@@ -4,11 +4,11 @@
 //              SpellChecker class methods
 //
 //  Part of:    Scid (Shane's Chess Information Database)
-//  Version:    3.2
+//  Version:    3.5
 //
-//  Notice:     Copyright (c) 2001-2002  Shane Hudson.  All rights reserved.
+//  Notice:     Copyright (c) 2001-2003  Shane Hudson.  All rights reserved.
 //
-//  Author:     Shane Hudson (shane@cosc.canterbury.ac.nz)
+//  Author:     Shane Hudson (sgh@users.sourceforge.net)
 //
 //////////////////////////////////////////////////////////////////////
 
@@ -62,6 +62,7 @@ SpellChecker::Init (void)
     for (uint h=0; h < SPELL_HASH_SIZE; h++) { HashNames[h] = NULL; }
     Prefixes = NULL;
     Suffixes = NULL;
+    Infixes = NULL;
 }
 
 void
@@ -85,7 +86,7 @@ SpellChecker::Destroy (void)
                 delete[] node->eloData;
             }
             if (node->renderName != NULL) { delete[] node->renderName; }
-            while (node->bioData != NULL) { 
+            while (node->bioData != NULL) {
                 bioNoteT * next = node->bioData->next;
                 delete[] node->bioData->text;
                 delete[] node->bioData;
@@ -109,6 +110,13 @@ SpellChecker::Destroy (void)
         delete Suffixes;
         Suffixes = next;
     }
+    while (Infixes != NULL) {
+        presuffixNodeT * next = Infixes->next;
+        delete[] Infixes->name;
+        delete[] Infixes->correctName;
+        delete Infixes;
+        Infixes = next;
+    }
 }
 
 void
@@ -212,6 +220,22 @@ SpellChecker::CorrectSuffix (const char * name, int * offset)
     return NULL;
 }
 
+const char *
+SpellChecker::CorrectInfix (const char * name, int * offset, int * replacedLength)
+{
+    presuffixNodeT * node = Infixes;
+    while (node != NULL) {
+        int index = strContainsIndex (name, node->name);
+        if (index >= 0) {
+            *offset = index;
+            *replacedLength = strLength (node->name);
+            return node->correctName;
+        }
+        node = node->next;
+    }
+    return NULL;
+}
+
 const char *
 SpellChecker::Correct (const char * name)
 {
@@ -277,17 +301,17 @@ getNameAndComment (char * line, char ** name, char ** comment)
             *comment = s;
         }
     }
-    
+
     // Strip leading spaces and trailling newline, tab and space chars:
     s = line;
-    while (*s == ' '  ||  *s == '\t') { s++; }
-    strTrimRight (s, " \t\n");
-    strTrimRight (*comment, " \t\n");
+    s = (char *) strTrimLeft(s);
+    strTrimRight (s);
+    strTrimRight (*comment);
     *name = s;
 }
 
 errorT
-SpellChecker::ReadSpellCheckFile (const char * filename)
+SpellChecker::ReadSpellCheckFile (const char * filename, bool checkPlayerOrder)
 {
     char line [1024];
     char strippedName [1024];
@@ -297,7 +321,6 @@ SpellChecker::ReadSpellCheckFile (const char * filename)
     char * lastRenderName = NULL;
     char * lastComment = NULL;
     nameT nameType = NAME_INVALID;
-    bool checkPlayerOrder = false;
 
     MFile fp;
     if (fp.Open (filename, FMODE_ReadOnly) != OK) { return ERROR_FileOpen; }
@@ -327,15 +350,11 @@ SpellChecker::ReadSpellCheckFile (const char * filename)
             if (lastCorrectNode != NULL  &&  strIsPrefix ("%Render ", name)) {
                 SetRenderName (lastCorrectNode, name+8);
             }
-            // "%CheckPlayerOrder" indicates a warning should be printed
-            // if any player name is out of order:
-            if (strIsPrefix ("%CheckPlayerOrder", name)) {
-                checkPlayerOrder = true;
-            }
             // Prefix or Suffix correction:
             if (nameType == NameType) {
                 if (strIsPrefix ("%Prefix ", name)) { AddPrefixSuffix (name); }
                 if (strIsPrefix ("%Suffix ", name)) { AddPrefixSuffix (name); }
+                if (strIsPrefix ("%Infix ", name))  { AddPrefixSuffix (name); }
             }
         } else if (*name == '@') {
             // Name type line: "@PLAYER", "@SITE", "@EVENT" or "@ROUND"
@@ -442,9 +461,14 @@ SpellChecker::AddPrefixSuffix (char * str)
     if (strIsPrefix ("%Suffix", str)) {
         node->next = Suffixes;
         Suffixes = node;
-    } else {
+    } else if (strIsPrefix ("%Prefix", str)) {
         node->next = Prefixes;
         Prefixes = node;
+    } else if (strIsPrefix ("%Infix", str)) {
+        node->next = Infixes;
+        Infixes = node;
+    } else {
+        return ERROR;
     }
     node->name = strDuplicate (q1);
     node->length = strLength (q1);
@@ -461,7 +485,7 @@ SpellChecker::AddBioData (spellCheckNodeT * node, const char * str)
     note->next = NULL;
     if (node->bioData == NULL) {
         node->bioData = note;
-        return; 
+        return;
     }
 
     bioNoteT * last = node->bioData;
@@ -499,7 +523,7 @@ SpellChecker::AddEloData (spellCheckNodeT * node, const char * str)
     }
     if (strIsPrefix ("%Elo ", str)) { str += 4; }
     while (1) {
-        str = strTrimLeft (str, ' ');
+        str = strTrimLeft (str);
         if (! isdigit (*str)) { break; }
         uint year = strGetUnsigned (str);
         str += 4;
@@ -522,7 +546,7 @@ SpellChecker::AddEloData (spellCheckNodeT * node, const char * str)
                 // Invalid data seen:
                 return;
             }
-              
+
             SetElo (node, year, quarter, elo);
             if (year >= ELO_FIRST_QUARTERLY_YEAR) {
                 quarter++;
@@ -649,7 +673,7 @@ SpellChecker::GetLastCountry (const char * comment)
     int length = 0;
     while (*end != ' '  &&  *end != 0) { end++; length++; }
     // Return the final three characters of the country field:
-    if (length >= 3) { 
+    if (length >= 3) {
         for (int i=0; i < 3; i++) { country[i] = start[length-3 + i]; }
         country[3] = 0;
     }
@@ -692,6 +716,28 @@ SpellChecker::GetBirthdate (const char * comment)
     return date_EncodeFromString (s);
 }
 
+//~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+// SpellChecker::GetDeathdate:
+//    Scan the player comment string for the deathdate
+//    field, convert it to a date, and return it.
+dateT
+SpellChecker::GetDeathdate (const char * comment)
+{
+    if (comment == NULL) { return ZERO_DATE; }
+    const char * s = comment;
+    // Find the end-bracket character after the rating:
+    while (*s != ']'  &&  *s != 0) { s++; }
+    if (*s != ']') { return ZERO_DATE; }
+    s++;
+    // Now skip over any spaces:
+    while (*s == ' ') { s++; }
+    // Now skip over the birthdate and dashes:
+    while (*s != 0  &&  *s != '-') { s++; }
+    while (*s == '-') { s++; }
+    if (*s == 0) { return ZERO_DATE; }
+    return date_EncodeFromString (s);
+}
+
 
 //////////////////////////////////////////////////////////////////////
 //  EOF: spellchk.cpp
