@@ -194,7 +194,7 @@ proc ::htext::init {w} {
 
   # PGN-window-specific tags:
   $w tag configure tag -foreground $::pgnColor(Header)
-  if { $::pgnMoveFont } {
+  if { $::::pgn::boldMainLine } {
      $w tag configure nag -foreground $::pgnColor(Nag) -font font_Regular
      $w tag configure var -foreground $::pgnColor(Var) -font font_Regular
   } else {
@@ -350,7 +350,7 @@ proc ::htext::display {w helptext {section ""} {fixed 1}} {
         set gameTag $tagName
         set tagName "g"
         set gnum [string range $gameTag 2 end]
-        set glCommand "gameLoadMenu $w [sc_base current] $gnum %X %Y"
+        set glCommand "::game::LoadMenu $w [sc_base current] $gnum %X %Y"
         $w tag bind $gameTag <ButtonPress-1> $glCommand
         $w tag bind $gameTag <ButtonPress-3> \
           "::gbrowser::new [sc_base current] $gnum"
@@ -378,14 +378,14 @@ proc ::htext::display {w helptext {section ""} {fixed 1}} {
         # Check if it is a comment tag:
         set commentTag $tagName
         set tagName "c"
-        if { $::pgnMoveFont } {
+        if { $::::pgn::boldMainLine } {
           $w tag configure $commentTag -foreground $::pgnColor(Comment) \
             -font font_Regular
         } else {
            $w tag configure $commentTag -foreground $::pgnColor(Comment) 
         }
         $w tag bind $commentTag <ButtonRelease-1> \
-          "sc_move pgn [string range $commentTag 2 end]; updateBoard; openCommentWin"
+          "sc_move pgn [string range $commentTag 2 end]; updateBoard; ::commenteditor::Open"
         $w tag bind $commentTag <Any-Enter> \
           "$w tag configure $commentTag -underline 1
            $w configure -cursor hand2"
@@ -460,7 +460,7 @@ proc ::htext::display {w helptext {section ""} {fixed 1}} {
       set imgName [string range $tagName 4 end]
       set winName $w.$imgName
       while {[winfo exists $winName]} { append winName a }
-      label $winName -image $imgName -relief flat -borderwidth 0
+      label $winName -image $imgName -relief flat -borderwidth 0 -background white
       $w window create end -window $winName
     }
     if {[strIsPrefix "button " $tagName]} {
