@@ -25,7 +25,7 @@ proc statusBarHelp {window {item {}}} {
   # I have no idea why it does this, but to avoid it we
   # convert a window paths with hashes to its true value:
 
-  if {[string range $window 0 1] == ".\#"} {
+  if {[string first {.#} $window] != -1} {
     set idx [string last . $window]
     set window [string range $window [expr {$idx+1} ] end]
     regsub -all "\#" $window . window
@@ -116,20 +116,20 @@ foreach menuname { file edit game search windows tools options helpmenu } {
 ### File menu:
 
 set m .menu.file
-$m add command -label FileNew -acc "Ctrl+N" -command fileNew
-bind . <Control-n> fileNew
+$m add command -label FileNew -acc "Ctrl+N" -command ::file::New
+bind . <Control-n> ::file::New
 set helpMessage($m,0) FileNew
 
-$m add command -label FileOpen -acc "Ctrl+O" -command fileOpen
-bind . <Control-o> fileOpen
+$m add command -label FileOpen -acc "Ctrl+O" -command ::file::Open
+bind . <Control-o> ::file::Open
 set helpMessage($m,1) FileOpen
 
-$m add command -label FileClose -acc "Ctrl+W" -command fileClose
-bind . <Control-w> fileClose
+$m add command -label FileClose -acc "Ctrl+W" -command ::file::Close
+bind . <Control-w> ::file::Close
 set helpMessage($m,2) FileClose
 
-$m add command -label FileFinder -acc "Ctrl+/" -command fileFinder
-bind . <Control-slash> fileFinder
+$m add command -label FileFinder -acc "Ctrl+/" -command ::file::finder::Open
+bind . <Control-slash> ::file::finder::Open
 set helpMessage($m,3) FileFinder
 
 $m add cascade -label FileBookmarks -accelerator "Ctrl+B" -menu $m.bookmarks
@@ -143,8 +143,8 @@ $m add cascade -label FileMaint -menu .menu.file.utils
 set helpMessage($m,6) FileMaint
 
 $m.utils add checkbutton -label FileMaintWin \
-  -accelerator "Ctrl+M" -variable maintWin -command makeMaintWin
-bind . <Control-m> makeMaintWin
+  -accelerator "Ctrl+M" -variable maintWin -command ::maint::OpenClose
+bind . <Control-m> ::maint::OpenClose
 set helpMessage($m.utils,0) FileMaintWin
 
 $m.utils add command -label FileMaintCompact -command makeCompactWin
@@ -187,7 +187,7 @@ set helpMessage($m.utils.name.3) FileMaintNameSite
 $m.utils.name add command -label FileMaintNameRound -command {openSpellCheckWin Round}
 set helpMessage($m.utils.name,4) FileMaintNameRound
 
-bind . <Control-d> makeBaseWin
+bind . <Control-d> ::windows::switcher::Open
 
 $m add command -label FileReadOnly -command makeBaseReadOnly
 set helpMessage($m,7) FileReadOnly
@@ -205,29 +205,18 @@ set currentSlot [sc_base current]
 for {set i 1} { $i <= $totalBaseSlots} {incr i} {
   $m.switch add radiobutton -variable currentSlot -value $i \
     -label "Base $i: <none>" \
-    -underline 5 -accelerator "Ctrl+$i" -command "switchBase $i"
+    -underline 5 -accelerator "Ctrl+$i" -command [list ::file::SwitchToBase $i]
   set helpMessage($m.switch,[expr {$i - 1} ]) "Switch to base slot $i"
   if {$i == $clipbaseSlot} {
     set helpMessage($m.switch,[expr {$i - 1} ]) "Switch to the clipbase database"
   }
-  bind . "<Control-Key-$i>" "switchBase $i"
-}
-
-proc switchBase {b} {
-  sc_base switch $b
-  # Close email window when a base is switched:
-  if {[winfo exists .emailWin]} { destroy .emailWin }
-  updateBoard -pgn
-  updateTitle
-  updateMenuStates
-  updateStatusBar
-  updateGList
+  bind . "<Control-Key-$i>" [list ::file::SwitchToBase $i]
 }
 
 $m add separator
 
-$m add command -label FileExit -accelerator "Ctrl+Q" -command fileExit
-bind . <Control-q> fileExit
+$m add command -label FileExit -accelerator "Ctrl+Q" -command ::file::Exit
+bind . <Control-q> ::file::Exit
 set helpMessage($m,10) FileExit
 
 
@@ -259,13 +248,13 @@ $m add cascade -label EditStrip -menu $m.strip
 set helpMessage($m,5) EditStrip
 
 menu $m.strip
-$m.strip add command -label EditStripComments -command {gameStrip comments}
+$m.strip add command -label EditStripComments -command {::game::Strip comments}
 set helpMessage($m.strip,0) EditStripComments
-$m.strip add command -label EditStripVars -command {gameStrip variations}
+$m.strip add command -label EditStripVars -command {::game::Strip variations}
 set helpMessage($m.strip,1) EditStripVars
-$m.strip add command -label EditStripBegin -command {gameTruncateBegin}
+$m.strip add command -label EditStripBegin -command {::game::TruncateBegin}
 set helpMessage($m.strip,2) EditStripBegin
-$m.strip add command -label EditStripEnd -command {gameTruncate}
+$m.strip add command -label EditStripEnd -command {::game::Truncate}
 set helpMessage($m.strip,3) EditStripEnd
 
 $m add separator
@@ -273,7 +262,7 @@ $m add separator
 $m add command -label EditReset -command {
   sc_clipbase clear
   updateBoard -pgn
-  updateGList
+  ::windows::gamelist::Refresh
   updateTitle
 }
 set helpMessage($m,7) EditReset
@@ -292,61 +281,64 @@ $m add command -label EditPaste -accelerator "Ctrl+V" -command {
 bind . <Control-v> {catch {sc_clipbase paste}; updateBoard -pgn}
 set helpMessage($m,9) EditPaste
 
+$m add command -label EditPastePGN -command importClipboardGame
+set helpMessage($m,10) EditPastePGN
+
 $m add separator
 
 $m add command -label EditSetup -accelerator "Ctrl+Shift+S" -command setupBoard
 bind . <Control-S> setupBoard
-set helpMessage($m,11) EditSetup
+set helpMessage($m,12) EditSetup
 
 $m add command -label EditCopyBoard -accelerator "Ctrl+Shift+C" \
   -command copyFEN
 bind . <Control-C> copyFEN
-set helpMessage($m,12) EditCopyBoard
+set helpMessage($m,13) EditCopyBoard
 
 $m add command -label EditPasteBoard -accelerator "Ctrl+Shift+V" \
   -command pasteFEN
 bind . <Control-V> pasteFEN
-set helpMessage($m,13) EditPasteBoard
+set helpMessage($m,14) EditPasteBoard
 
 
 ### Game menu:
 
 set m .menu.game
-$m add command -label GameNew -accelerator "Ctrl+X" -command gameClear
-bind . <Control-x> gameClear
+$m add command -label GameNew -accelerator "Ctrl+X" -command ::game::Clear
+bind . <Control-x> ::game::Clear
 set helpMessage($m,0) GameNew
 
 $m add command -label GameFirst -accelerator "Ctrl+Shift+Up" \
-  -command {gameLoadNextPrev first}
-bind . <Control-Shift-Up> {gameLoadNextPrev first}
+  -command {::game::LoadNextPrev first}
+bind . <Control-Shift-Up> {::game::LoadNextPrev first}
 set helpMessage($m,1) GameFirst
 
 $m add command -label GamePrev -accelerator "Ctrl+Up" \
-  -command {gameLoadNextPrev previous}
-bind . <Control-Up> {gameLoadNextPrev previous}
+  -command {::game::LoadNextPrev previous}
+bind . <Control-Up> {::game::LoadNextPrev previous}
 set helpMessage($m,2) GamePrev
 
-$m add command -label GameReload -command gameReload \
+$m add command -label GameReload -command ::game::Reload \
   -accelerator "Ctrl+Shift+L"
-bind . <Control-L> gameReload
+bind . <Control-L> ::game::Reload
 set helpMessage($m,3) GameReload
 
 $m add command -label GameNext -accelerator "Ctrl+Down" \
-  -command {gameLoadNextPrev next}
-bind . <Control-Down> {gameLoadNextPrev next}
+  -command {::game::LoadNextPrev next}
+bind . <Control-Down> {::game::LoadNextPrev next}
 set helpMessage($m,4) GameNext
 
 $m add command -label GameLast -accelerator "Ctrl+Shift+Down" \
-  -command {gameLoadNextPrev last}
-bind . <Control-Shift-Down> {gameLoadNextPrev last}
+  -command {::game::LoadNextPrev last}
+bind . <Control-Shift-Down> {::game::LoadNextPrev last}
 set helpMessage($m,5) GameLast
 
-$m add command -label GameRandom -command gameLoadRandom -accelerator "Ctrl+?"
-bind . <Control-question> gameLoadRandom
+$m add command -label GameRandom -command ::game::LoadRandom -accelerator "Ctrl+?"
+bind . <Control-question> ::game::LoadRandom
 set helpMessage($m,6) GameRandom
 
-$m add command -label GameNumber -command gameLoadNumber -accelerator "Ctrl+G"
-bind . <Control-g> gameLoadNumber
+$m add command -label GameNumber -command ::game::LoadNumber -accelerator "Ctrl+G"
+bind . <Control-g> ::game::LoadNumber
 set helpMessage($m,7) GameNumber
 
 $m add separator
@@ -369,9 +361,9 @@ bind . <Control-D> {sc_move ply [sc_eco game ply]; updateBoard}
 set helpMessage($m,12) GameDeepest
 
 $m add command -label GameGotoMove -accelerator "Ctrl+U" \
-  -command gotoMoveNumber
+  -command ::game::GotoMoveNumber
 set helpMessage($m,13) GameGotoMove
-bind . <Control-u> gotoMoveNumber
+bind . <Control-u> ::game::GotoMoveNumber
 
 $m add command -label GameNovelty -accelerator "Ctrl+Shift+Y" \
   -command findNovelty
@@ -382,57 +374,40 @@ set helpMessage($m,14) GameNovelty
 ### Search menu:
 
 set m .menu.search
-$m  add command -label SearchReset -acc "Ctrl+F" -command searchReset
-bind . <Control-f> searchReset
+$m  add command -label SearchReset -acc "Ctrl+F" \
+  -command ::search::filter::reset
+bind . <Control-f> search::filter::reset
 set helpMessage($m,0) SearchReset
 
-$m  add command -label SearchNegate -acc "Ctrl+Shift+F" -command searchNegate
-bind . <Control-F> searchNegate
+$m  add command -label SearchNegate -acc "Ctrl+Shift+F" \
+  -command ::search::filter::negate
+bind . <Control-F> ::search::filter::negate
 set helpMessage($m,1) SearchNegate
 
 $m  add separator
 
 $m  add command -label SearchCurrent \
-  -command searchBoard -accelerator "Ctrl+Shift+B"
-bind . <Control-B> searchBoard
+  -command ::search::board -accelerator "Ctrl+Shift+B"
+bind . <Control-B> ::search::board
 set helpMessage($m,3) SearchCurrent
 
 $m  add command -label SearchHeader \
-  -command searchHeader -accelerator "Ctrl+Shift+H"
-bind . <Control-H> searchHeader
+  -command ::search::header -accelerator "Ctrl+Shift+H"
+bind . <Control-H> ::search::header
 set helpMessage($m,4) SearchHeader
 
 $m  add command -label SearchMaterial \
-  -command searchMaterial -accelerator "Ctrl+Shift+M"
-bind . <Control-M> searchMaterial
+  -command ::search::material -accelerator "Ctrl+Shift+M"
+bind . <Control-M> ::search::material
 set helpMessage($m,5) SearchMaterial
 
 $m  add separator
 
 $m add command -label SearchUsing -accel "Ctrl+Shift+U" \
-  -command useSearchFile
-bind . <Control-KeyPress-U> useSearchFile
+  -command ::search::usefile
+bind . <Control-KeyPress-U> ::search::usefile
 set helpMessage($m,7) SearchUsing
 
-proc useSearchFile {} {
-  set ftype { { "Scid SearchOption files" {".sso"} } }
-  set ::fName [tk_getOpenFile -initialdir $::initialDir(base) \
-                 -filetypes $ftype -title "Select a SearchOptions file"]
-  if {$::fName == ""} { return }
-
-  if {[catch {uplevel "#0" {source $::fName} } ]} {
-    tk_messageBox -title "Scid: Error reading file" -type ok -icon warning \
-                -message "Unable to open or read SearchOptions file: $fName"
-  } else {
-    switch -- $::searchType {
-      "Material" { searchMaterial }
-      "Header"   { searchHeader }
-      default    { return }
-    }
-  }
-}
-
-
 ### Windows menu:
 
 set m .menu.windows
@@ -442,13 +417,13 @@ bind . <Control-e> makeCommentWin
 set helpMessage($m,0) WindowsComment
 
 $m  add checkbutton -label WindowsGList \
-  -variable glist -command makeGList  -accelerator "Ctrl+L"
-bind . <Control-l> makeGList
+  -variable ::windows::gamelist::isOpen -command ::windows::gamelist::Open  -accelerator "Ctrl+L"
+bind . <Control-l> ::windows::gamelist::Open
 set helpMessage($m,1) WindowsGList
 
 $m  add checkbutton -label WindowsPGN \
-  -variable pgnWin -command makePgnWin  -accelerator "Ctrl+P"
-bind . <Control-p> makePgnWin
+  -variable pgnWin -command ::pgn::OpenClose  -accelerator "Ctrl+P"
+bind . <Control-p> ::pgn::OpenClose
 set helpMessage($m,2) WindowsPGN
 
 $m add checkbutton -label WindowsPList \
@@ -464,29 +439,29 @@ set helpMessage($m,4) WindowsTmt
 $m add separator
 
 $m add checkbutton -label WindowsSwitcher \
-  -variable baseWin -accelerator "Ctrl+D" -command makeBaseWin
+  -variable baseWin -accelerator "Ctrl+D" -command ::windows::switcher::Open
 set helpMessage($m,6) WindowsSwitcher
 
 $m add checkbutton -label WindowsMaint \
-  -accelerator "Ctrl+M" -variable maintWin -command makeMaintWin
-bind . <Control-m> makeMaintWin
+  -accelerator "Ctrl+M" -variable maintWin -command ::maint::OpenClose
+bind . <Control-m> ::maint::OpenClose
 set helpMessage($m,7) WindowsMaint
 
 $m add separator
 
 $m add checkbutton -label WindowsECO -accelerator "Ctrl+Y" \
-  -variable ecoBrowserWin -command {openCloseEcoBrowser}
-bind . <Control-y> openCloseEcoBrowser
+  -variable ::windows::eco::isOpen -command {::windows::eco::OpenClose}
+bind . <Control-y> ::windows::eco::OpenClose
 set helpMessage($m,9) WindowsECO
 
 $m add checkbutton -label WindowsRepertoire -variable ::rep::Win \
-  -accelerator "Ctrl+Shift+R" -command ::rep::openCloseWindow
-bind . <Control-R> ::rep::openCloseWindow
+  -accelerator "Ctrl+Shift+R" -command ::rep::OpenCloseWindow
+bind . <Control-R> ::rep::OpenCloseWindow
 set helpMessage($m,10) WindowsRepertoire
 
-$m add checkbutton -label WindowsStats -variable statsWin \
-  -accelerator "Ctrl+I" -command makeStatsWin
-bind . <Control-i> makeStatsWin
+$m add checkbutton -label WindowsStats -variable ::windows::stats::isOpen \
+  -accelerator "Ctrl+I" -command ::windows::stats::Open
+bind . <Control-i> ::windows::stats::Open
 set helpMessage($m,11) WindowsStats
 
 $m add checkbutton -label WindowsTree \
@@ -494,9 +469,9 @@ $m add checkbutton -label WindowsTree \
 bind . <Control-t> { .menu.windows invoke [tr WindowsTree] }
 set helpMessage($m,12) WindowsTree
 
-$m add checkbutton -label WindowsTB -variable tbWin -command ::tb::open \
+$m add checkbutton -label WindowsTB -variable ::tb::isOpen -command ::tb::Open \
   -accelerator "Ctrl+="
-bind . <Control-equal> ::tb::open
+bind . <Control-equal> ::tb::Open
 set helpMessage($m,13) WindowsTB
 
 
@@ -520,13 +495,13 @@ bind . <Control-X> crosstabWin
 set helpMessage($m,2) ToolsCross
 
 $m add checkbutton -label ToolsEmail \
-  -accelerator "Ctrl+Shift+E" -variable emailWin -command makeEmailWin
-bind . <Control-E> makeEmailWin
+  -accelerator "Ctrl+Shift+E" -variable emailWin -command ::tools::email
+bind . <Control-E> ::tools::email
 set helpMessage($m,3) ToolsEmail
 
 $m add checkbutton -label ToolsFilterGraph \
-  -accelerator "Ctrl+Shift+G" -variable filterGraph -command makeFilterGraph
-bind . <Control-G> makeFilterGraph
+  -accelerator "Ctrl+Shift+G" -variable filterGraph -command tools::graphs::filter::Open
+bind . <Control-G> tools::graphs::filter::Open
 set helpMessage($m,4) ToolsFilterGraph
 
 $m add command -label ToolsOpReport \
@@ -554,13 +529,13 @@ set helpMessage($m,8) ToolsPInfo
 $m add command -label ToolsPlayerReport -command ::preport::preportDlg
 set helpMessage($m.9) ToolsPlayerReport
 
-$m add command -label ToolsRating -command {updateRatingGraph both}
-# bind . <Control-R> {updateRatingGraph both}
+$m add command -label ToolsRating -command {::tools::graphs::rating::Refresh both}
+# bind . <Control-R> {::tools::graphs::rating::Refresh both}
 set helpMessage($m,10) ToolsRating
 
 $m add command -label ToolsScore \
-  -accelerator "Ctrl+Shift+Z" -command updateScoreGraph
-bind . <Control-Z> updateScoreGraph
+  -accelerator "Ctrl+Shift+Z" -command ::tools::graphs::score::Refresh
+bind . <Control-Z> ::tools::graphs::score::Refresh
 set helpMessage($m,11) ToolsScore
 
 $m add separator
@@ -621,8 +596,11 @@ foreach menu $optMenus label $optLabels {
   incr i
 }
 
+$m add command -label OptionsSounds -command ::utils::sound::OptionsDialog
+set helpMessage($m,9) OptionsSounds
+
 $m add command -label OptionsToolbar -command configToolbar
-set helpMessage($m,9) OptionsToolbar
+set helpMessage($m,10) OptionsToolbar
 
 $m add separator
 
@@ -643,13 +621,13 @@ $m add command -label OptionsECO -command {
     }
   }
 }
-set helpMessage($m,11) OptionsECO
+set helpMessage($m,12) OptionsECO
 
 $m add command -label OptionsSpell -command readSpellCheckFile
-set helpMessage($m,12) OptionsSpell
+set helpMessage($m,13) OptionsSpell
 
 $m add command -label OptionsTable -command setTableBaseDir
-set helpMessage($m,13) OptionsTable
+set helpMessage($m,14) OptionsTable
 if {![sc_info tb]} { $m entryconfigure 13 -state disabled }
 
 # setTableBaseDir:
@@ -728,7 +706,7 @@ proc chooseTableBaseDir {i} {
 }
 
 $m add command -label OptionsRecent -command ::recentFiles::configure
-set helpMessage($m,14) OptionsRecent
+set helpMessage($m,15) OptionsRecent
 
 $m add separator
 
@@ -744,15 +722,16 @@ $m add command -label OptionsSave -command {
     puts $optionF "# If you edit this file, you must preserve valid its Tcl"
     puts $optionF "# format or it will not set your Scid options properly."
     puts $optionF ""
-    foreach i {boardSize boardStyle language doColorPgn \
-                 pgnIndentVars pgnIndentComments pgnShortHeader pgnMoveFont \
-                 pgnSymbolicNags pgnMoveNumSpace pgnColumn myPlayerNames \
+    foreach i {boardSize boardStyle language ::pgn::showColor \
+                 ::pgn::indentVars ::pgn::indentComments \
+                 ::pgn::shortHeader ::pgn::boldMainLine \
+                 ::pgn::symbolicNags ::pgn::moveNumberSpaces ::pgn::columnFormat myPlayerNames \
                  tree(order) tree(autoSave) optionsAutoSave \
                  ecoFile suggestMoves glistSize glexport \
                  autoplayDelay animateDelay boardCoords boardSTM \
                  moveEntry(AutoExpand) moveEntry(Coord) \
-                 askToReplaceMoves switcherVertical locale(numeric) \
-                 spellCheckFile autoCloseSplash autoRaise autoIconify \
+                 askToReplaceMoves ::windows::switcher::vertical locale(numeric) \
+                 spellCheckFile ::splash::autoclose autoRaise autoIconify \
                  exportFlags(comments) exportFlags(vars) \
                  exportFlags(indentc) exportFlags(indentv) \
                  exportFlags(column) exportFlags(symbols) \
@@ -761,7 +740,9 @@ $m add command -label OptionsSave -command {
                  email(from) email(bcc) \
                  gameInfo(photos) gameInfo(hideNextMove) gameInfo(wrap) \
                  gameInfo(fullComment) gameInfo(showMarks) \
-                 gameInfo(showMaterial) gameInfo(showFEN) gameInfo(showTB)} {
+                 gameInfo(showMaterial) gameInfo(showFEN) gameInfo(showTB) \
+                 ::utils::sound::soundFolder ::utils::sound::announceNew \
+                 ::utils::sound::announceForward ::utils::sound::announceBack} {
       puts $optionF "set $i [list [set $i]]"
     }
     puts $optionF ""
@@ -789,8 +770,8 @@ $m add command -label OptionsSave -command {
     foreach i [lsort [array names optable]] {
       puts $optionF "set optable($i) [list $optable($i)]"
     }
-    foreach i [lsort [array names stats]] {
-      puts $optionF "set stats($i) [list $stats($i)]"
+    foreach i [lsort [array names ::windows::stats::display]] {
+      puts $optionF "set ::windows::stats::display($i) [list $::windows::stats::display($i)]"
     }
     foreach i [lsort [array names startup]] {
       puts $optionF "set startup($i) [list $startup($i)]"
@@ -802,7 +783,7 @@ $m add command -label OptionsSave -command {
       puts $optionF "set twinSettings($i) [list $twinSettings($i)]"
     }
     puts $optionF ""
-    foreach i {Regular Menu Small Fixed} {
+    foreach i {Regular Menu Small Tiny Fixed} {
       puts $optionF "set fontOptions($i) [list $fontOptions($i)]"
     }
     puts $optionF ""
@@ -819,10 +800,10 @@ $m add command -label OptionsSave -command {
     set ::statusBar "Options were saved to: [scidConfigFile options]"
   }
 }
-set helpMessage($m,16) OptionsSave
+set helpMessage($m,17) OptionsSave
 
 $m add checkbutton -label OptionsAutoSave -variable optionsAutoSave
-set helpMessage($m,17) OptionsAutoSave
+set helpMessage($m,18) OptionsAutoSave
 
 menu $m.ginfo
 $m.ginfo add checkbutton -label GInfoHideNext \
@@ -879,7 +860,7 @@ set helpMessage($m.entry,5) OptionsMovesSuggest
 proc updateLocale {} {
   global locale
   sc_info decimal $locale(numeric)
-  updateGList
+  ::windows::gamelist::Refresh
   updateTitle
 }
 
@@ -912,6 +893,7 @@ menu .menu.options.language
 
 set m .menu.options.fonts
 menu $m
+
 $m add command -label OptionsFontsRegular -underline 0 -command {
   set fontOptions(temp) [FontDialog font_Regular $fontOptions(Regular)]
   if {$fontOptions(temp) != ""} { set fontOptions(Regular) $fontOptions(temp) }
@@ -927,11 +909,13 @@ $m add command -label OptionsFontsRegular -underline 0 -command {
   font configure font_H5 -family $font -size [expr {$fontsize + 0} ]
 }
 set helpMessage($m,0) OptionsFontsRegular
+
 $m add command -label OptionsFontsMenu -underline 0 -command {
   set fontOptions(temp) [FontDialog font_Menu $fontOptions(Menu)]
   if {$fontOptions(temp) != ""} { set fontOptions(Menu) $fontOptions(temp) }
 }
 set helpMessage($m,1) OptionsFontsMenu
+
 $m add command -label OptionsFontsSmall -underline 0 -command {
   set fontOptions(temp) [FontDialog font_Small $fontOptions(Small)]
   if {$fontOptions(temp) != ""} { set fontOptions(Small) $fontOptions(temp) }
@@ -941,6 +925,7 @@ $m add command -label OptionsFontsSmall -underline 0 -command {
   font configure font_SmallItalic -family $font -size $fontsize
 }
 set helpMessage($m,2) OptionsFontsSmall
+
 $m add command -label OptionsFontsFixed -underline 0 -command {
   set fontOptions(temp) [FontDialog font_Fixed $fontOptions(Fixed) 1]
   if {$fontOptions(temp) != ""} { set fontOptions(Fixed) $fontOptions(temp) }
@@ -1071,7 +1056,7 @@ proc updateMenuStates {} {
   set idx [$m.file index end]
   incr idx
   $m.file add command -label [tr FileExit] -accelerator "Ctrl+Q" \
-    -command fileExit
+    -command ::file::Exit
   set helpMessage($m.file,$idx) FileExit
 
   # Configure File menu entry states::
@@ -1165,10 +1150,10 @@ proc updateMenuStates {} {
   if {[baseIsCompactable]} { set state normal }
   $m.file.utils entryconfig [tr FileMaintCompact] -state $state
 
-  configSearchState
-  updateBaseWin
-  updateMaintWin
-  ::bookmarks::refresh
+  ::search::Config
+  ::windows::switcher::Refresh
+  ::maint::Refresh
+  ::bookmarks::Refresh
 }
 
 
@@ -1224,7 +1209,7 @@ proc setLanguageMenus {{lang ""}} {
     configMenuText .menu.file.utils.name [tr FileMaintName$tag $oldLang] \
       FileMaintName$tag $lang
   }
-  foreach tag {Add Delete First Main Trial Strip Reset Copy Paste Setup
+  foreach tag {Add Delete First Main Trial Strip Reset Copy Paste PastePGN Setup
                CopyBoard PasteBoard} {
     configMenuText .menu.edit [tr Edit$tag $oldLang] Edit$tag $lang
   }
@@ -1257,7 +1242,7 @@ proc setLanguageMenus {{lang ""}} {
     configMenuText .menu.tools.exportfilter [tr $tag $oldLang] $tag $lang
   }
   foreach tag {Board Export Fonts GInfo Language Moves Numbers
-               Startup Toolbar Windows ECO Spell Table Recent Save AutoSave} {
+               Startup Sounds Toolbar Windows ECO Spell Table Recent Save AutoSave} {
     configMenuText .menu.options [tr Options$tag $oldLang] Options$tag $lang
   }
   foreach tag {Regular Menu Small Fixed} {
@@ -1301,13 +1286,13 @@ proc setLanguageMenus {{lang ""}} {
     incr i
   }
 
-  configPgnMenus
-  configStatsMenus
-  ::tree::configMenus
-  configCrosstabMenus
-  ::optable::configMenus
-  ::preport::configMenus
-  ::tourney::configMenus
+  ::pgn::ConfigMenus
+  ::windows::stats::ConfigMenus
+  ::tree::ConfigMenus
+  ::crosstab::ConfigMenus
+  ::optable::ConfigMenus
+  ::preport::ConfigMenus
+  ::tourney::ConfigMenus
 
   # Check for duplicate menu underline characters in this language:
   # set ::verifyMenus 1
@@ -1353,40 +1338,40 @@ proc checkMenuUnderline {menu} {
 #
 proc standardShortcuts {w} {
   if {! [winfo exists $w]} { return }
-  bind $w <Control-o> fileOpen
-  bind $w <Control-w> fileClose
-  bind $w <Control-slash> fileFinder
-  bind $w <Control-m> makeMaintWin
-  bind $w <Control-d> makeBaseWin
-  bind $w <Control-q> fileExit
-  bind $w <Control-L> gameReload
-  bind $w <Control-Shift-Up> {gameLoadNextPrev first}
-  bind $w <Control-Shift-Down> {gameLoadNextPrev last}
-  bind $w <Control-Up> {gameLoadNextPrev previous}
-  bind $w <Control-Down> {gameLoadNextPrev next}
-  bind $w <Control-question> gameLoadRandom
-  bind $w <Control-g> gameLoadNumber
-  bind $w <Control-f> searchReset
-  bind $w <Control-B> searchBoard
-  bind $w <Control-H> searchHeader
-  bind $w <Control-M> searchMaterial
-  bind $w <Control-KeyPress-U> useSearchFile
+  bind $w <Control-o> ::file::Open
+  bind $w <Control-w> ::file::Close
+  bind $w <Control-slash> ::file::finder::Open
+  bind $w <Control-m> ::maint::OpenClose
+  bind $w <Control-d> ::windows::switcher::Open
+  bind $w <Control-q> ::file::Exit
+  bind $w <Control-L> ::game::Reload
+  bind $w <Control-Shift-Up> {::game::LoadNextPrev first}
+  bind $w <Control-Shift-Down> {::game::LoadNextPrev last}
+  bind $w <Control-Up> {::game::LoadNextPrev previous}
+  bind $w <Control-Down> {::game::LoadNextPrev next}
+  bind $w <Control-question> ::game::LoadRandom
+  bind $w <Control-g> ::game::LoadNumber
+  bind $w <Control-f> ::search::filter::reset
+  bind $w <Control-B> ::search::board
+  bind $w <Control-H> ::search::header
+  bind $w <Control-M> ::search::material
+  bind $w <Control-KeyPress-U> ::search:::usefile
   bind $w <Control-e> makeCommentWin
-  bind $w <Control-l> makeGList
-  bind $w <Control-p> makePgnWin
+  bind $w <Control-l> ::windows::gamelist::Open
+  bind $w <Control-p> ::pgn::OpenClose
   bind $w <Control-T> ::tourney::toggle
-  bind $w <Control-i> makeStatsWin
+  bind $w <Control-i> ::windows::stats::Open
   bind $w <Control-t> ::tree::make
   bind $w <Control-A> makeAnalysisWin
   bind $w <Control-X> crosstabWin
-  bind $w <Control-E> makeEmailWin
+  bind $w <Control-E> ::tools::email
   bind $w <Control-O> ::optable::makeReportWin
-  # bind $w <Control-R> {updateRatingGraph both}
-  bind $w <Control-R> ::rep::openCloseWindow
-  bind $w <Control-Z> updateScoreGraph
+  # bind $w <Control-R> {::tools::graphs::rating::Refresh both}
+  bind $w <Control-R> ::rep::OpenCloseWindow
+  bind $w <Control-Z> ::tools::graphs::score::Refresh
   bind $w <Control-I> importPgnGame
   for {set i 1} { $i <= $::totalBaseSlots} {incr i} {
-    bind $w "<Control-Key-$i>" "switchBase $i"
+    bind $w "<Control-Key-$i>" "::file::SwitchToBase $i"
   }
 }
 
