@@ -2,9 +2,11 @@
 
 # Scid (Shane's Chess Information Database)
 #
-# Copyright (C) 1999--2003  Shane Hudson. All rights reserved.
-# This is freely redistributable software; see the file named COPYING
-# that came with this program.
+# Copyright (C) 1999-2004  Shane Hudson. All rights reserved.
+#
+# This is freely redistributable software; see the file named "COPYING"
+# or "copying.txt" that came with this program.
+#
 # To contact the author, email Shane at: sgh@users.sourceforge.net
 
 #
@@ -23,7 +25,7 @@ exec tkscid "$0" "$@"
 
 ############################################################
 
-set scidVersion "3.5"
+set scidVersion "3.6"
 
 # Determine operating system platform: unix or windows
 #
@@ -49,14 +51,52 @@ if {[string compare [sc_info version] $scidVersion]} {
     set msg "This is Scid version [sc_info version], but the scid.gui data\n"
     append msg "file has the version number $scidVersion.\n"
   } else {
-    set msg "This program,\n\"$argv0\",\nhas version $scidVersion,\nbut the "
-    append msg "tkscid program \nit uses has version [sc_info version].\n"
+    set msg "This program,\n\"$argv0\",\nis version $scidVersion,\nbut the "
+    append msg "tkscid program \nit uses is version [sc_info version].\n"
     append msg "Check that the path to tkscid is correct." 
   }
   tk_messageBox -type ok -icon error -title "Scid: Version Error" -message $msg
   exit 1
 }
 
+# Alter the version if any patches have been made to the Tcl code only:
+set scidVersion "3.6.1"
+set scidVersionDate "03 March 2004"
+
+#############################################################
+#
+# NAMESPACES
+#
+# The main Tcl/Tk namespaces used in the Scid application are
+# initialized here, so that default values can be set up and
+# altered when the user options file is loaded.
+#
+foreach ns {
+  ::splash
+  ::utils
+    ::utils::date ::utils::font ::utils::history ::utils::pane ::utils::string
+    ::utils::sound ::utils::validate ::utils::win
+  ::file
+    ::file::finder ::file::maint ::maint
+    ::bookmarks
+  ::edit
+  ::game
+    ::gbrowser
+  ::search
+    ::search::filter ::search::board ::search::header ::seach::material
+  ::windows
+    ::windows::gamelist ::windows::stats ::tree ::windows::tree
+    ::windows::switcher ::windows::eco ::crosstab ::pgn
+  ::tools
+    ::tools::analysis ::tools::email
+    ::tools::graphs
+      ::tools::graphs::filter ::tools::graphs::rating ::tools::graphs::score
+    ::tb ::optable
+  ::board ::move
+} {
+  namespace eval $ns {}
+}
+
 
 #############################################################
 # Customisable variables:
@@ -84,7 +124,7 @@ set scidLogDir [file nativename [file join $scidUserDir "log"]]
 # this first, and if that fails, it will try to load  "scid.eco" in the
 # current directory.
 if {$windowsOS} {
-  set ecoFile [file join $scidExeDir "scid.eco"]
+  set ecoFile [file join $scidDataDir "scid.eco"]
 } else {
   set ecoFile "/usr/local/share/scid/scid.eco"
 }
@@ -94,7 +134,7 @@ set boardSizes [list 25 30 35 40 45 50 55 60 65 70]
 set boardSizesOLD [list 21 25 29 33 37 40 45 49 54 58 64 72]
 
 # boardSize: Default board size. See the available board sizes above.
-set boardSize 45
+set boardSize 40
 
 # boardStyle: Default board piece set. See bitmaps.tcl for styles.
 set boardStyle Alpha
@@ -139,17 +179,20 @@ if {$windowsOS} {
   set fontOptions(Regular) [list Arial           10 normal roman]
   set fontOptions(Menu)    [list {MS Sans Serif}  9 normal roman]
   set fontOptions(Small)   [list Arial            9 normal roman]
+  set fontOptions(Tiny)    [list Arial            8 normal roman]
   set fontOptions(Fixed)   [list Courier          9 normal roman]
 } else {
   set fontOptions(Regular) [list helvetica 11 normal roman]
   set fontOptions(Menu)    [list helvetica 10 normal roman]
   set fontOptions(Small)   [list helvetica 10 normal roman]
+  set fontOptions(Tiny)    [list helvetica  9 normal roman]
   set fontOptions(Fixed)   [list fixed     10 normal roman]
 }
 
 createFont Regular
 createFont Menu
 createFont Small
+createFont Tiny
 createFont Fixed
 
 # Analysis command: to start chess analysis engine.
@@ -176,16 +219,16 @@ set buttoncolor "\#b0c0d0"
 set borderwidth 1
 
 # Defaults for the PGN window:
-# if doColorPgn is 1, the PGN text will be colorized.
-set doColorPgn 1
-set pgnIndentVars 1
-set pgnIndentComments 1
-set pgnSymbolicNags 1
-set pgnMoveNumSpace 0
-set pgnShortHeader 0
-set pgnMoveFont 1
-set pgnColumn 0
-set pgnStripMarks 0
+# if ::pgn::showColor is 1, the PGN text will be colorized.
+set ::pgn::showColor 1
+set ::pgn::indentVars 1
+set ::pgn::indentComments 1
+set ::pgn::symbolicNags 1
+set ::pgn::moveNumberSpaces 0
+set ::pgn::shortHeader 0
+set ::pgn::boldMainLine 1
+set ::pgn::columnFormat 0
+set ::pgn::stripMarks 0
 set pgnColor(Header) "\#00008b"
 set pgnColor(Main) "\#000000"
 set pgnColor(Var) "\#0000ee"
@@ -250,7 +293,7 @@ set winWidth(.treeWin)  58
 set winHeight(.treeWin) 20
 
 # Default comment editor size:
-set winWidth(.commentWin)  50
+set winWidth(.commentWin)  40
 set winHeight(.commentWin)  6
 
 # Default spellcheck results window size:
@@ -261,9 +304,12 @@ set winHeight(.spellcheckWin) 25
 set winWidth(.playerInfoWin)  45
 set winHeight(.playerInfoWin) 20
 
+# Default switcher window size:
+set winWidth(.baseWin) 310
+set winHeight(.baseWin) 110
 
 # Default stats window lines:
-array set stats {
+array set ::windows::stats::display {
   r2600 1
   r2500 1
   r2400 1
@@ -279,10 +325,11 @@ array set stats {
   y1990 0
   y1992 0
   y1994 0
-  y1996 1
+  y1996 0
   y1998 1
   y2000 1
   y2001 1
+  y2002 1
 }
 
 # Default PGN display options:
@@ -507,11 +554,12 @@ foreach type {PGN HTML LaTeX} {
 }
 
 
-# switcherVertical:
+# ::windows::switcher::vertical
+#
 #   If 1, Switcher frames are arranged vertically.
-
-set switcherVertical 0
-
+#
+set ::windows::switcher::vertical 0
+set ::windows::switcher::icons 1
 
 # autoRaise: defines whether the "raise" command should be used to raise
 # certain windows (like progress bars) when they become obscured.
@@ -547,6 +595,14 @@ set email(from) ""
 set email(bcc) ""
 
 
+### Audio move announcement options:
+
+set ::utils::sound::soundFolder [file nativename [file join $::scidExeDir sounds]]
+set ::utils::sound::announceNew 0
+set ::utils::sound::announceForward 0
+set ::utils::sound::announceBack 0
+
+
 # Spell-checking file: default is "spelling.ssp".
 if {$windowsOS} {
   set spellCheckFile [file join $scidDataDir "spelling.ssp"]
@@ -583,42 +639,50 @@ proc updateStatusBar {} {}
 
 # Start up splash screen:
 
-set autoCloseSplash 1
-wm withdraw .
-toplevel .splash
-wm protocol .splash WM_DELETE_WINDOW { wm withdraw .splash }
-wm title .splash "Welcome to Scid [sc_info version]"
-frame .splash.f
-frame .splash.b
-text .splash.t -height 14 -width 50 -cursor top_left_arrow \
+set ::splash::autoclose 1
+
+proc ::splash::make {} {
+  wm withdraw .
+  set w [toplevel .splash]
+  wm withdraw $w
+  wm protocol $w WM_DELETE_WINDOW [list wm withdraw $w]
+  wm title $w "Welcome to Scid $::scidVersion"
+  frame $w.f
+  frame $w.b
+  text $w.t -height 15 -width 60 -cursor top_left_arrow \
     -background white -font font_Regular -wrap word \
-    -yscrollcommand {.splash.ybar set} -setgrid 1
-scrollbar .splash.ybar -command {.splash.t yview}
-checkbutton .splash.auto -text "Auto-close after startup" \
-  -variable autoCloseSplash -font font_Small -pady 5 -padx 5
-button .splash.dismiss -text " Close " -command {wm withdraw .splash} \
-  -font font_Small
-pack .splash.f -side top -expand yes -fill both
-pack .splash.b -side top -fill x
-pack .splash.auto -side left -in .splash.b -pady 2 -ipadx 10 -padx 10
-pack .splash.dismiss -side right -in .splash.b -pady 2 -ipadx 10 -padx 10
-pack .splash.ybar -in .splash.f -side right -fill y
-pack .splash.t -in .splash.f -side left -fill both -expand yes
+    -yscrollcommand [list $w.ybar set] -setgrid 1
+  scrollbar $w.ybar -command [list $w.t yview]
+  checkbutton $w.auto -text "Auto-close after startup" \
+    -variable ::splash::autoclose -font font_Small -pady 5 -padx 5
+  button $w.dismiss -text Close -width 8 -command [list wm withdraw $w] \
+    -font font_Small
+  pack $w.f -side top -expand yes -fill both
+  pack $w.b -side top -fill x
+  pack $w.auto -side left -in .splash.b -pady 2 -ipadx 10 -padx 10
+  pack $w.dismiss -side right -in .splash.b -pady 2 -ipadx 10 -padx 10
+  pack $w.ybar -in $w.f -side right -fill y
+  pack $w.t -in $w.f -side left -fill both -expand yes
 
-bind .splash <F1> {helpWindow Index}
-bind .splash <Escape> {.splash.dismiss invoke}
+  # Centre the splash window:
+  update idletasks
+  set x [expr {[winfo screenwidth $w]/2 - [winfo reqwidth $w]/2 \
+                 - [winfo vrootx .]}]
+  set y [expr {[winfo screenheight $w]/2 - [winfo reqheight $w]/2 \
+                 - [winfo vrooty .]}]
+  wm geom $w +$x+$y
+  wm deiconify $w
 
-.splash.t tag configure indent -lmargin2 20
+  bind $w <F1> {helpWindow Index}
+  bind $w <Escape> {.splash.dismiss invoke}
 
-proc addSplash {text} {
-    if {! [winfo exists .splash]} {return}
-    .splash.t configure -state normal
-    .splash.t insert end "\n$text" indent
-    .splash.t see end
-    .splash.t configure -state disabled
-    update
+  $w.t tag configure indent -lmargin2 20
+
+  $w.t image create end -image splash
+  $w.t insert end "Shane's Chess Information Database"
 }
 
+
 # Old Scid logo:
 image create photo splash -format gif -data \
 "R0lGODdhZgAmAMIAAP///6CBUNHBoQAAcAAAAFK4bgAAAAAAACwAAAAAZgAmAAAD/gi63P4w
@@ -717,16 +781,26 @@ sAMvnAk1yBoM7KEWv9olFXN+Q0OdoJIB6WAoS1IhLUJBvTogUPGrS3MR5REuQIOs8LIw3Lk3
 eoGp4WkYkYCVQ6MQF/MBwZAr3xkQADs=
 }
 
-.splash.t image create end -image splash
-.splash.t insert end "Shane's Chess Information Database"
-addSplash "Copyright (C) 1999-2003 Shane Hudson  (sgh@users.sourceforge.net)"
-addSplash "This is Scid [sc_info version], released [sc_info version date]."
-addSplash "Website: scid.sourceforge.net\n"
+::splash::make
+
+proc ::splash::add {text} {
+    if {! [winfo exists .splash]} {return}
+    .splash.t configure -state normal
+    .splash.t insert end "\n$text" indent
+    .splash.t see end
+    .splash.t configure -state disabled
+    update
+}
+
+::splash::add "Copyright (C) 1999-2004 Shane Hudson  (sgh@users.sourceforge.net)"
+::splash::add "This is Scid $::scidVersion, released $::scidVersionDate."
+::splash::add "Website: scid.sourceforge.net\n"
 
 # Remember old font settings before loading options file:
 set fontOptions(oldRegular) $fontOptions(Regular)
 set fontOptions(oldMenu) $fontOptions(Menu)
 set fontOptions(oldSmall) $fontOptions(Small)
+set fontOptions(oldTiny) $fontOptions(Tiny)
 set fontOptions(oldFixed) $fontOptions(Fixed)
 
 # New configuration file names:
@@ -734,6 +808,7 @@ set scidConfigFiles(options) "options.dat"
 set scidConfigFiles(engines) "engines.dat"
 set scidConfigFiles(engines.bak) "engines.dat"
 set scidConfigFiles(recentfiles) "recent.dat"
+set scidConfigFiles(history) "history.dat"
 set scidConfigFiles(bookmarks) "bookmarks.dat"
 set scidConfigFiles(reports) "reports.dat"
 
@@ -766,7 +841,7 @@ if {! [file isdirectory $scidUserDir]} {
     catch {file rename -force $scidUserDir "$scidUserDir.old"}
   }
   if {[catch {file mkdir $scidUserDir} err]} {
-    addSplash "Error creating ~/.scid directory: $err"
+    ::splash::add "Error creating ~/.scid directory: $err"
   } else {
     catch {file rename "$scidUserDir.old" $optionsFile}
   }
@@ -780,9 +855,9 @@ if {! [file isdirectory $scidUserDir]} {
 proc makeScidDir {dir} {
   if {! [file isdirectory $dir]} {
     if {[catch {file mkdir $dir} err]} {
-      addSplash "Error creating directory $dir: $err"
+      ::splash::add "Error creating directory $dir: $err"
     } else {
-      addSplash "Created directory: $dir"
+      ::splash::add "Created directory: $dir"
     }
   }
 }
@@ -813,9 +888,9 @@ proc moveOldConfigFiles {} {
     set newpath [file nativename [file join $scidConfigDir $newname]]
     if {[file readable $oldpath]  &&  ![file readable $newpath]} {
       if {[catch {file rename $oldpath $newpath} err]} {
-        addSplash "Error moving $oldpath to $newpath: $err"
+        ::splash::add "Error moving $oldpath to $newpath: $err"
       } else {
-        addSplash "Moved old config file $oldname to $newpath"
+        ::splash::add "Moved old config file $oldname to $newpath"
       }
     }
   }
@@ -826,13 +901,43 @@ moveOldConfigFiles
 set optionsFile [scidConfigFile options]
 
 if {[catch {source $optionsFile} ]} {
-  #addSplash "Unable to find the options file: [file tail $optionsFile]"
+  #::splash::add "Unable to find the options file: [file tail $optionsFile]"
 } else {
-  addSplash "Your options file \"[file tail $optionsFile]\" was found and loaded."
+  ::splash::add "Your options file \"[file tail $optionsFile]\" was found and loaded."
 }
 
+# Now, if the options file was written by Scid 3.5 or older, it has a lot of
+# yucky variable names in the global namespace. So convert them to the new
+# namespace variables:
+#
+proc ConvertOldOptionVariables {} {
+
+  set oldNewNames {
+    autoCloseSplash ::splash::autoclose
+    switcherVertical ::windows::switcher::vertical
+    doColorPgn ::pgn::showColor
+    pgnIndentVars ::pgn::indentVars
+    pgnIndentComments ::pgn::indentComments
+    pgnShortHeader ::pgn::shortHeader
+    pgnMoveFont ::pgn::boldMainLine
+    pgnMoveNumSpace ::pgn::moveNumberSpaces
+    pgnStripMarks ::pgn::stripMarks
+    pgnSymbolicNags ::pgn::symbolicNags
+    pgnColumn ::pgn::columnFormat
+  }
+
+  foreach {old new} $oldNewNames {
+    if {[info exists ::$old]} {
+      set $new [set ::$old]
+    }
+  }
+}
+
+ConvertOldOptionVariables
+
+
 # Reconfigure fonts if necessary:
-foreach i {Regular Menu Small Fixed} {
+foreach i {Regular Menu Small Tiny Fixed} {
   if {$fontOptions($i) == $fontOptions(old$i)} {
     # Old font format in options file, or no file. Extract new options:
     set fontOptions($i) {}
@@ -895,6 +1000,8 @@ set font [font configure font_Small -family]
 font create font_SmallBold -family $font -size $fontsize -weight bold
 font create font_SmallItalic -family $font -size $fontsize -slant italic
 
+# Start in the clipbase, if no database is loaded at startup.
+sc_base switch clipbase
 
 ###
 ### End of file: start.tcl
